@@ -88,6 +88,10 @@ int PresenceModelExtended::rowCount(const QModelIndex &parent) const
 
 QVariant PresenceModelExtended::data(const QModelIndex &index, int role) const
 {
+    if (role == Qt::SizeHintRole) {
+        const QFontMetrics fontMetrics(KGlobalSettings::generalFont());
+        return QSize(0, qMax(fontMetrics.height(), (int)(KIconLoader::SizeSmall)) + 8);
+    }
     if (index.row() == rowCount(index.parent())-1) {
         switch(role) {
         case Qt::DisplayRole:
@@ -137,14 +141,20 @@ void PresenceModelExtended::sourceRowsRemoved(const QModelIndex &index, int star
 
 QModelIndex PresenceModelExtended::addTemporaryPresence(const KTp::Presence &presence)
 {
-    if (! presence.isValid()) {
-        removeTemporaryPresence();
+    int row = m_model->rowCount(QModelIndex());
+
+    //if the temp presence already exists, don't remove and readd it
+    //but simply replace it
+    if (m_temporaryPresence.isValid()) {
+        m_temporaryPresence = presence;
+        emit dataChanged(this->createIndex(row, 0), this->createIndex(row, 0));
+    } else {
+        kDebug() << "adding temp presence to the model";
+        beginInsertRows(QModelIndex(),row, row);
+        m_temporaryPresence = presence;
+        endInsertRows();
     }
 
-    int row = m_model->rowCount(QModelIndex());
-    beginInsertRows(QModelIndex(),row, row);
-    m_temporaryPresence = presence;
-    endInsertRows();
     return this->createIndex(row, 0);
 }
 
@@ -260,6 +270,12 @@ bool GlobalPresenceChooser::event(QEvent *e)
                 m_changePresenceMessageButton->show();
             }
         }
+        if (ke->key() == Qt::Key_Down || ke->key() == Qt::Key_Up) {
+            if (!isEditable()) {
+                showPopup();
+                return true;
+            }
+        }
     }
 
     if (e->type() == QEvent::FocusOut) {
@@ -341,12 +357,13 @@ void GlobalPresenceChooser::onCurrentIndexChanged(int index)
 
 void GlobalPresenceChooser::onPresenceChanged(const KTp::Presence &presence)
 {
-    m_modelExtended->removeTemporaryPresence();
-    kDebug();
     for (int i=0; i < count() ; i++) {
         KTp::Presence itemPresence = itemData(i, PresenceModel::PresenceRole).value<KTp::Presence>();
         if (itemPresence.type() == presence.type() && itemPresence.statusMessage() == presence.statusMessage()) {
             setCurrentIndex(i);
+            if (itemPresence != m_modelExtended->temporaryPresence()) {
+                m_modelExtended->removeTemporaryPresence();
+            }
             return;
         }
     }
